import logging

import pm.config

def configure_log():
    logger = logging.getLogger()
    
    if pm.config.IS_DEBUG is True:
        logger.setLevel(logging.DEBUG)
    else:
        logger.setLevel(logging.INFO)

    ch = logging.StreamHandler()

    formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
    ch.setFormatter(formatter)
    logger.addHandler(ch)



import json

def pretty_json_dump(data, f):
    json.dump(
        data,
        f,
        sort_keys=True,
        indent=4, 
        separators=(',', ': '))

    f.write("\n")

def pretty_json_dumps(data):
    return json.dumps(
            data,
            sort_keys=True,
            indent=4, 
            separators=(',', ': ')) + "\n"
